@@ -19,16 +19,19 @@ Classes
 
 """
 
-__version__ = '0.19.2'
+__version__ = '1.6.2'
 
 from .core import *  # noqa: F401 F403
 from .artists import *  # noqa: F401 F403
 
-from .geometryplotter import GeometryPlotter  # noqa: F401
-
+from .geometryplotter import GeometryPlotter
 from .plotter import Plotter  # noqa: F401
-from .networkplotter import NetworkPlotter  # noqa: F401
-from .meshplotter import MeshPlotter  # noqa: F401
+from .networkplotter import NetworkPlotter
+from .meshplotter import MeshPlotter
 
 
-__all__ = [name for name in dir() if not name.startswith('_')]
+__all__ = [
+    'GeometryPlotter',
+    'NetworkPlotter',
+    'MeshPlotter'
+]
